@@ -1,7 +1,7 @@
 package App::picadata;
 use v5.14.1;
 
-our $VERSION = '1.26';
+our $VERSION = '1.27';
 
 use Getopt::Long qw(GetOptionsFromArray :config bundling);
 use Pod::Usage;
@@ -262,8 +262,8 @@ sub run {
 
         $record = $record->sort if $self->{order};
 
-        $record = {record => $record->fields(@pathes)} if @pathes;
-        next unless @{$record->{record}};    # ignore empty records
+        $record->{record} = $record->fields(@pathes) if @pathes;
+        return if $record->empty;
 
         # TODO: also validate on other commands?
         if ($command eq 'validate') {
@@ -285,9 +285,10 @@ sub run {
         $builder->add($record)  if $builder;
 
         if ($command eq 'count') {
-            $stats->{holdings} += @{$record->holdings};
-            $stats->{items}    += @{$record->items};
-            $stats->{fields}   += @{$record->{record}};
+            $stats->{holdings}
+                += grep {@{$_->fields('1...')}} @{$record->holdings};
+            $stats->{items}  += grep {!$_->empty} @{$record->items};
+            $stats->{fields} += @{$record->{record}};
         }
         $stats->{records}++;
 
@@ -329,12 +330,10 @@ sub run {
     else {
         foreach my $in (@{$self->{input}}) {
             my $parser = $self->parser_from_input($in);
-            while (my $record = $parser->next) {
-                if ($command eq 'split') {
-                    $process->($_) for $record->split;
-                }
-                else {
-                    $process->($record);
+            while (my $next = $parser->next) {
+                for ($command eq 'split' ? $next->split : $next) {
+                    $process->($_);
+                    last if $number and $stats->{records} >= $number;
                 }
             }
         }
