@@ -1,7 +1,7 @@
 package PICA::Parser::Base;
 use v5.14.1;
 
-our $VERSION = '1.26';
+our $VERSION = '1.27';
 
 use Carp qw(croak);
 use Scalar::Util qw(reftype);
@@ -12,7 +12,6 @@ sub _new {
     my (%options) = @_ % 2 ? (fh => @_) : @_;
 
     bless {
-        bless    => !!$options{bless},
         strict   => !!$options{strict},
         fh       => defined $options{fh} ? $options{fh} : \*STDIN,
         annotate => $options{annotate}
@@ -57,8 +56,7 @@ sub next {
         next unless @$record;
         my ($id) = map {$_->[-1]} grep {($_->[0] // '') =~ '003@'} @$record;
         $record = {_id => $id, record => $record};
-        bless $record, 'PICA::Data' if $self->{bless};
-        return $record;
+        return bless $record, 'PICA::Data';
     }
 
     return;
@@ -81,7 +79,7 @@ PICA::Parser::Base - abstract base class of PICA parsers
     }
 
     use PICA::Parser::Plus;
-    my $parser = PICA::Parser::Plus->new( $filename, bless => 1 );
+    my $parser = PICA::Parser::Plus->new( $filename );
     ... # records will be instances of PICA::Data
 
     use PICA::Parser::XML;
@@ -113,10 +111,6 @@ Use one of the following subclasses instead:
 
 =over
 
-=item blessed
-
-Return records as instances of L<PICA::Data> (disabled by default).
-
 =item strict
 
 By default faulty fields in records are skipped with warnings. You can make
@@ -138,8 +132,8 @@ reference to a Unicode string. L<PICA::Parser::XML> also detects plain XML strin
 
 =head2 next
 
-Reads the next PICA+ record. Returns a (optionally blessed) hash with keys
-C<_id> and C<record>, as defined in L<PICA::Data>.
+Reads the next PICA+ record. Returns a L<PICA::Data> object (that is a blessed
+hash with keys C<record> and optional C<_id>).
 
 =head1 SEE ALSO
 
